blob: dcd9ad955b41c26664a7c364845044e5345a3fe4 [file]
<?xml version='1.0' encoding='UTF-8' standalone='no'?>
<doxygen xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="compound.xsd" version="1.9.8" xml:lang="en-US">
<compounddef id="byte__array__input__stream_8h" kind="file" language="C++">
<compoundname>byte_array_input_stream.h</compoundname>
<includes local="no">cstdint</includes>
<includes local="no">functional</includes>
<includes local="no">string</includes>
<includes refid="file__system_8h" local="yes">paimon/fs/file_system.h</includes>
<includes refid="result_8h" local="yes">paimon/result.h</includes>
<includes refid="status_8h" local="yes">paimon/status.h</includes>
<includes refid="visibility_8h" local="yes">paimon/visibility.h</includes>
<includedby refid="roaring__bitmap32_8h" local="yes">/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/utils/roaring_bitmap32.h</includedby>
<includedby refid="roaring__bitmap64_8h" local="yes">/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/utils/roaring_bitmap64.h</includedby>
<incdepgraph>
<node id="5">
<label>paimon/fs/file_system.h</label>
<link refid="file__system_8h"/>
<childnode refid="2" relation="include">
</childnode>
<childnode refid="3" relation="include">
</childnode>
<childnode refid="6" relation="include">
</childnode>
<childnode refid="4" relation="include">
</childnode>
<childnode refid="7" relation="include">
</childnode>
<childnode refid="8" relation="include">
</childnode>
<childnode refid="12" relation="include">
</childnode>
<childnode refid="20" relation="include">
</childnode>
</node>
<node id="1">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/io/byte_array_input_stream.h</label>
<link refid="byte__array__input__stream_8h"/>
<childnode refid="2" relation="include">
</childnode>
<childnode refid="3" relation="include">
</childnode>
<childnode refid="4" relation="include">
</childnode>
<childnode refid="5" relation="include">
</childnode>
<childnode refid="8" relation="include">
</childnode>
<childnode refid="12" relation="include">
</childnode>
<childnode refid="20" relation="include">
</childnode>
</node>
<node id="8">
<label>paimon/result.h</label>
<link refid="result_8h"/>
<childnode refid="9" relation="include">
</childnode>
<childnode refid="10" relation="include">
</childnode>
<childnode refid="11" relation="include">
</childnode>
<childnode refid="12" relation="include">
</childnode>
<childnode refid="21" relation="include">
</childnode>
</node>
<node id="12">
<label>paimon/status.h</label>
<link refid="status_8h"/>
<childnode refid="13" relation="include">
</childnode>
<childnode refid="14" relation="include">
</childnode>
<childnode refid="6" relation="include">
</childnode>
<childnode refid="4" relation="include">
</childnode>
<childnode refid="11" relation="include">
</childnode>
<childnode refid="15" relation="include">
</childnode>
<childnode refid="16" relation="include">
</childnode>
<childnode refid="17" relation="include">
</childnode>
<childnode refid="20" relation="include">
</childnode>
</node>
<node id="17">
<label>paimon/string_builder.h</label>
<link refid="string__builder_8h"/>
<childnode refid="6" relation="include">
</childnode>
<childnode refid="18" relation="include">
</childnode>
<childnode refid="19" relation="include">
</childnode>
<childnode refid="4" relation="include">
</childnode>
<childnode refid="11" relation="include">
</childnode>
<childnode refid="20" relation="include">
</childnode>
</node>
<node id="20">
<label>paimon/visibility.h</label>
<link refid="visibility_8h"/>
</node>
<node id="9">
<label>cassert</label>
</node>
<node id="2">
<label>cstdint</label>
</node>
<node id="13">
<label>cstring</label>
</node>
<node id="3">
<label>functional</label>
</node>
<node id="14">
<label>iosfwd</label>
</node>
<node id="6">
<label>memory</label>
</node>
<node id="18">
<label>ostream</label>
</node>
<node id="15">
<label>paimon/compare.h</label>
</node>
<node id="16">
<label>paimon/macros.h</label>
</node>
<node id="21">
<label>paimon/traits.h</label>
</node>
<node id="19">
<label>sstream</label>
</node>
<node id="4">
<label>string</label>
</node>
<node id="10">
<label>type_traits</label>
</node>
<node id="11">
<label>utility</label>
</node>
<node id="7">
<label>vector</label>
</node>
</incdepgraph>
<invincdepgraph>
<node id="5">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/api.h</label>
<link refid="api_8h"/>
</node>
<node id="3">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/file_index/bitmap_index_result.h</label>
<link refid="bitmap__index__result_8h"/>
</node>
<node id="8">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/format/file_format.h</label>
<link refid="file__format_8h"/>
</node>
<node id="7">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/format/reader_builder.h</label>
<link refid="reader__builder_8h"/>
<childnode refid="8" relation="include">
</childnode>
</node>
<node id="12">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/global_index/bitmap_global_index_result.h</label>
<link refid="bitmap__global__index__result_8h"/>
</node>
<node id="13">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/global_index/bitmap_scored_global_index_result.h</label>
<link refid="bitmap__scored__global__index__result_8h"/>
</node>
<node id="15">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/global_index/global_index_reader.h</label>
<link refid="global__index__reader_8h"/>
<childnode refid="16" relation="include">
</childnode>
<childnode refid="17" relation="include">
</childnode>
</node>
<node id="16">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/global_index/global_index_scan.h</label>
<link refid="global__index__scan_8h"/>
</node>
<node id="17">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/global_index/global_indexer.h</label>
<link refid="global__indexer_8h"/>
</node>
<node id="1">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/io/byte_array_input_stream.h</label>
<link refid="byte__array__input__stream_8h"/>
<childnode refid="2" relation="include">
</childnode>
<childnode refid="11" relation="include">
</childnode>
</node>
<node id="14">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/predicate/full_text_search.h</label>
<link refid="full__text__search_8h"/>
<childnode refid="15" relation="include">
</childnode>
</node>
<node id="4">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/reader/batch_reader.h</label>
<link refid="batch__reader_8h"/>
<childnode refid="5" relation="include">
</childnode>
<childnode refid="6" relation="include">
</childnode>
<childnode refid="10" relation="include">
</childnode>
</node>
<node id="6">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/reader/file_batch_reader.h</label>
<link refid="file__batch__reader_8h"/>
<childnode refid="7" relation="include">
</childnode>
<childnode refid="9" relation="include">
</childnode>
</node>
<node id="9">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/reader/prefetch_file_batch_reader.h</label>
<link refid="prefetch__file__batch__reader_8h"/>
</node>
<node id="10">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/table/source/table_read.h</label>
<link refid="table__read_8h"/>
<childnode refid="5" relation="include">
</childnode>
</node>
<node id="2">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/utils/roaring_bitmap32.h</label>
<link refid="roaring__bitmap32_8h"/>
<childnode refid="3" relation="include">
</childnode>
<childnode refid="4" relation="include">
</childnode>
<childnode refid="6" relation="include">
</childnode>
<childnode refid="11" relation="include">
</childnode>
</node>
<node id="11">
<label>/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/utils/roaring_bitmap64.h</label>
<link refid="roaring__bitmap64_8h"/>
<childnode refid="12" relation="include">
</childnode>
<childnode refid="13" relation="include">
</childnode>
<childnode refid="14" relation="include">
</childnode>
</node>
</invincdepgraph>
<innerclass refid="classpaimon_1_1_byte_array_input_stream" prot="public">paimon::ByteArrayInputStream</innerclass>
<innernamespace refid="namespacepaimon">paimon</innernamespace>
<briefdescription>
</briefdescription>
<detaileddescription>
</detaileddescription>
<programlisting>
<codeline lineno="1"><highlight class="comment">/*</highlight></codeline>
<codeline lineno="2"><highlight class="comment"><sp/>*<sp/>Licensed<sp/>to<sp/>the<sp/>Apache<sp/>Software<sp/>Foundation<sp/>(ASF)<sp/>under<sp/>one</highlight></codeline>
<codeline lineno="3"><highlight class="comment"><sp/>*<sp/>or<sp/>more<sp/>contributor<sp/>license<sp/>agreements.<sp/><sp/>See<sp/>the<sp/>NOTICE<sp/>file</highlight></codeline>
<codeline lineno="4"><highlight class="comment"><sp/>*<sp/>distributed<sp/>with<sp/>this<sp/>work<sp/>for<sp/>additional<sp/>information</highlight></codeline>
<codeline lineno="5"><highlight class="comment"><sp/>*<sp/>regarding<sp/>copyright<sp/>ownership.<sp/><sp/>The<sp/>ASF<sp/>licenses<sp/>this<sp/>file</highlight></codeline>
<codeline lineno="6"><highlight class="comment"><sp/>*<sp/>to<sp/>you<sp/>under<sp/>the<sp/>Apache<sp/>License,<sp/>Version<sp/>2.0<sp/>(the</highlight></codeline>
<codeline lineno="7"><highlight class="comment"><sp/>*<sp/>&quot;License&quot;);<sp/>you<sp/>may<sp/>not<sp/>use<sp/>this<sp/>file<sp/>except<sp/>in<sp/>compliance</highlight></codeline>
<codeline lineno="8"><highlight class="comment"><sp/>*<sp/>with<sp/>the<sp/>License.<sp/><sp/>You<sp/>may<sp/>obtain<sp/>a<sp/>copy<sp/>of<sp/>the<sp/>License<sp/>at</highlight></codeline>
<codeline lineno="9"><highlight class="comment"><sp/>*</highlight></codeline>
<codeline lineno="10"><highlight class="comment"><sp/>*<sp/><sp/><sp/>http://www.apache.org/licenses/LICENSE-2.0</highlight></codeline>
<codeline lineno="11"><highlight class="comment"><sp/>*</highlight></codeline>
<codeline lineno="12"><highlight class="comment"><sp/>*<sp/>Unless<sp/>required<sp/>by<sp/>applicable<sp/>law<sp/>or<sp/>agreed<sp/>to<sp/>in<sp/>writing,</highlight></codeline>
<codeline lineno="13"><highlight class="comment"><sp/>*<sp/>software<sp/>distributed<sp/>under<sp/>the<sp/>License<sp/>is<sp/>distributed<sp/>on<sp/>an</highlight></codeline>
<codeline lineno="14"><highlight class="comment"><sp/>*<sp/>&quot;AS<sp/>IS&quot;<sp/>BASIS,<sp/>WITHOUT<sp/>WARRANTIES<sp/>OR<sp/>CONDITIONS<sp/>OF<sp/>ANY</highlight></codeline>
<codeline lineno="15"><highlight class="comment"><sp/>*<sp/>KIND,<sp/>either<sp/>express<sp/>or<sp/>implied.<sp/><sp/>See<sp/>the<sp/>License<sp/>for<sp/>the</highlight></codeline>
<codeline lineno="16"><highlight class="comment"><sp/>*<sp/>specific<sp/>language<sp/>governing<sp/>permissions<sp/>and<sp/>limitations</highlight></codeline>
<codeline lineno="17"><highlight class="comment"><sp/>*<sp/>under<sp/>the<sp/>License.</highlight></codeline>
<codeline lineno="18"><highlight class="comment"><sp/>*/</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="19"><highlight class="normal"></highlight></codeline>
<codeline lineno="20"><highlight class="normal"></highlight><highlight class="preprocessor">#pragma<sp/>once</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="21"><highlight class="normal"></highlight></codeline>
<codeline lineno="22"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&lt;cstdint&gt;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="23"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&lt;functional&gt;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="24"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&lt;string&gt;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="25"><highlight class="normal"></highlight></codeline>
<codeline lineno="26"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&quot;<ref refid="file__system_8h" kindref="compound">paimon/fs/file_system.h</ref>&quot;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="27"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&quot;<ref refid="result_8h" kindref="compound">paimon/result.h</ref>&quot;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="28"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&quot;<ref refid="status_8h" kindref="compound">paimon/status.h</ref>&quot;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="29"><highlight class="normal"></highlight><highlight class="preprocessor">#include<sp/>&quot;<ref refid="visibility_8h" kindref="compound">paimon/visibility.h</ref>&quot;</highlight><highlight class="normal"></highlight></codeline>
<codeline lineno="30"><highlight class="normal"></highlight></codeline>
<codeline lineno="31"><highlight class="normal"></highlight><highlight class="keyword">namespace<sp/></highlight><highlight class="normal"><ref refid="namespacepaimon" kindref="compound">paimon</ref><sp/>{</highlight></codeline>
<codeline lineno="33" refid="classpaimon_1_1_byte_array_input_stream" refkind="compound"><highlight class="keyword">class<sp/></highlight><highlight class="normal"><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">PAIMON_EXPORT</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream" kindref="compound">ByteArrayInputStream</ref><sp/>:<sp/></highlight><highlight class="keyword">public</highlight><highlight class="normal"><sp/><ref refid="classpaimon_1_1_input_stream" kindref="compound">InputStream</ref><sp/>{</highlight></codeline>
<codeline lineno="34"><highlight class="normal"><sp/></highlight><highlight class="keyword">public</highlight><highlight class="normal">:</highlight></codeline>
<codeline lineno="35" refid="classpaimon_1_1_byte_array_input_stream_1a27adfcd95ed6aaaf80f0e4aff3434b53" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a27adfcd95ed6aaaf80f0e4aff3434b53" kindref="member">ByteArrayInputStream</ref>(</highlight><highlight class="keyword">const</highlight><highlight class="normal"><sp/></highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/>buffer,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint64_t</ref><sp/>length);</highlight></codeline>
<codeline lineno="36" refid="classpaimon_1_1_byte_array_input_stream_1a3f67c44fbd4538999d957dce4c6b8d74" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a3f67c44fbd4538999d957dce4c6b8d74" kindref="member">~ByteArrayInputStream</ref>()<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal"><sp/>=<sp/></highlight><highlight class="keywordflow">default</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="37"><highlight class="normal"></highlight></codeline>
<codeline lineno="39" refid="classpaimon_1_1_byte_array_input_stream_1aa88cc72ea6b2b2246678a4b8a26df27d" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/></highlight><highlight class="keyword">const</highlight><highlight class="normal"><sp/></highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1aa88cc72ea6b2b2246678a4b8a26df27d" kindref="member">GetRawData</ref>()<sp/></highlight><highlight class="keyword">const</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="40"><highlight class="normal"></highlight></codeline>
<codeline lineno="41" refid="classpaimon_1_1_byte_array_input_stream_1a126079b40c47569c924fd569547166f8" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_status" kindref="compound">Status</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a126079b40c47569c924fd569547166f8" kindref="member">Seek</ref>(<ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">int64_t</ref><sp/>offset,<sp/><ref refid="namespacepaimon_1ac1eb532d87b4e6a9ea64431b61e115f9" kindref="member">SeekOrigin</ref><sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">origin</ref>)<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="42"><highlight class="normal"></highlight></codeline>
<codeline lineno="43" refid="classpaimon_1_1_byte_array_input_stream_1a6b6c3122b49d821ca0cee14ba2234e46" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_result" kindref="compound">Result&lt;int64_t&gt;</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a6b6c3122b49d821ca0cee14ba2234e46" kindref="member">GetPos</ref>()</highlight><highlight class="keyword"><sp/>const<sp/>override<sp/></highlight><highlight class="normal">{</highlight></codeline>
<codeline lineno="44"><highlight class="normal"><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/></highlight><highlight class="keywordflow">return</highlight><highlight class="normal"><sp/>position_;</highlight></codeline>
<codeline lineno="45"><highlight class="normal"><sp/><sp/><sp/><sp/>}</highlight></codeline>
<codeline lineno="46"><highlight class="normal"></highlight></codeline>
<codeline lineno="47" refid="classpaimon_1_1_byte_array_input_stream_1a1a565b1e7a9a59d1afaee634bd2817a3" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_result" kindref="compound">Result&lt;int32_t&gt;</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a1a565b1e7a9a59d1afaee634bd2817a3" kindref="member">Read</ref>(</highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/>buffer,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint32_t</ref><sp/>size)<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="48"><highlight class="normal"></highlight></codeline>
<codeline lineno="49" refid="classpaimon_1_1_byte_array_input_stream_1a12175ba9fe216be489c690182bb5c001" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_result" kindref="compound">Result&lt;int32_t&gt;</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a12175ba9fe216be489c690182bb5c001" kindref="member">Read</ref>(</highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/>buffer,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint32_t</ref><sp/>size,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint64_t</ref><sp/>offset)<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="50"><highlight class="normal"></highlight></codeline>
<codeline lineno="51" refid="classpaimon_1_1_byte_array_input_stream_1a56ee03f22c6ee8851ae8663a1a6833bd" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/></highlight><highlight class="keywordtype">void</highlight><highlight class="normal"><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a56ee03f22c6ee8851ae8663a1a6833bd" kindref="member">ReadAsync</ref>(</highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/>buffer,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint32_t</ref><sp/>size,<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint64_t</ref><sp/>offset,</highlight></codeline>
<codeline lineno="52"><highlight class="normal"><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/>std::function&lt;</highlight><highlight class="keywordtype">void</highlight><highlight class="normal">(<ref refid="classpaimon_1_1_status" kindref="compound">Status</ref>)&gt;&amp;&amp;<sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">callback</ref>)<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="53"><highlight class="normal"></highlight></codeline>
<codeline lineno="54" refid="classpaimon_1_1_byte_array_input_stream_1a1d699eac070340e49bc034ad011807fd" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_result" kindref="compound">Result&lt;uint64_t&gt;</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1a1d699eac070340e49bc034ad011807fd" kindref="member">Length</ref>()</highlight><highlight class="keyword"><sp/>const<sp/>override<sp/></highlight><highlight class="normal">{</highlight></codeline>
<codeline lineno="55"><highlight class="normal"><sp/><sp/><sp/><sp/><sp/><sp/><sp/><sp/></highlight><highlight class="keywordflow">return</highlight><highlight class="normal"><sp/>length_;</highlight></codeline>
<codeline lineno="56"><highlight class="normal"><sp/><sp/><sp/><sp/>}</highlight></codeline>
<codeline lineno="57"><highlight class="normal"></highlight></codeline>
<codeline lineno="58" refid="classpaimon_1_1_byte_array_input_stream_1af8f33c3d0216d1cef8e332be2e94852f" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_status" kindref="compound">Status</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1af8f33c3d0216d1cef8e332be2e94852f" kindref="member">Close</ref>()<sp/></highlight><highlight class="keyword">override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="59"><highlight class="normal"></highlight></codeline>
<codeline lineno="60" refid="classpaimon_1_1_byte_array_input_stream_1ada7a88c0744aaa95255e4cc631ebb762" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="classpaimon_1_1_result" kindref="compound">Result&lt;std::string&gt;</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1ada7a88c0744aaa95255e4cc631ebb762" kindref="member">GetUri</ref>()<sp/></highlight><highlight class="keyword">const<sp/>override</highlight><highlight class="normal">;</highlight></codeline>
<codeline lineno="61"><highlight class="normal"></highlight></codeline>
<codeline lineno="62"><highlight class="normal"><sp/></highlight><highlight class="keyword">private</highlight><highlight class="normal">:</highlight></codeline>
<codeline lineno="63" refid="classpaimon_1_1_byte_array_input_stream_1aad7457b827c1dc14894ac61a298a78ea" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/></highlight><highlight class="keyword">const</highlight><highlight class="normal"><sp/></highlight><highlight class="keywordtype">char</highlight><highlight class="normal">*<sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1aad7457b827c1dc14894ac61a298a78ea" kindref="member">buffer_</ref>;</highlight></codeline>
<codeline lineno="64" refid="classpaimon_1_1_byte_array_input_stream_1ad10233758bd425c83b0899ac1c35b851" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/></highlight><highlight class="keyword">const</highlight><highlight class="normal"><sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">uint64_t</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1ad10233758bd425c83b0899ac1c35b851" kindref="member">length_</ref>;</highlight></codeline>
<codeline lineno="65" refid="classpaimon_1_1_byte_array_input_stream_1af8bd602151823bb24eb9721c747d314a" refkind="member"><highlight class="normal"><sp/><sp/><sp/><sp/><ref refid="memory__pool_8h_1a147ba4ba34a215b3a4f3a95c1ee11704" kindref="member">int64_t</ref><sp/><ref refid="classpaimon_1_1_byte_array_input_stream_1af8bd602151823bb24eb9721c747d314a" kindref="member">position_</ref>;</highlight></codeline>
<codeline lineno="66"><highlight class="normal">};</highlight></codeline>
<codeline lineno="67"><highlight class="normal">}<sp/><sp/></highlight><highlight class="comment">//<sp/>namespace<sp/>paimon</highlight><highlight class="normal"></highlight></codeline>
</programlisting>
<location file="/home/runner/work/paimon-cpp/paimon-cpp/include/paimon/io/byte_array_input_stream.h"/>
</compounddef>
</doxygen>